@@ -221,7 +221,7 @@ class HierarchicalClassifier(BaseEstimator, ClassifierMixin):
         `custom_node_data` can override 'sub_target', 'hyperparameters', and 'cv'
         """
         # Attributes must be ordered in the way the model was originally fit
-        assert all([name,clf,attributes]), "Must provide `name`, `clf`, and `attributes`"
+        assert all([name is not None, clf is not None, attributes is not None]), "Must provide `name`, `clf`, and `attributes`"
         if hyperparameters is None:
             hyperparameters = clf.get_params()
         # Check to make sure that if the cross-validation is predefined, that index is not None, and all indicies are in index
