@@ -8,16 +8,23 @@ import os, sys, time
 # I/O
 # ===
 from .bioinformatics import *
+from .datasets import *
 from .objects import *
 from .tables import *
 from .text import *
 from .web import *
 
-_bioinformatics = ["read_clustalo_distmat", "read_vizbin_coords", "read_checkm_qa", "read_fasta", "write_fasta", "read_blast", "read_gff3", "read_gtf", "read_ncbi_xml", "read_ebi_sample_metadata"]
+_bioinformatics = [
+"read_clustalo_distmat", "read_vizbin_coords", "read_checkm_qa", "read_fasta", 
+"write_fasta", "read_blast", "read_gtf_gff_base", "read_gff3", "read_gtf", "read_ncbi_xml", "read_ebi_sample_metadata",
+"read_star_log", "read_hmmer",
+]
+_datasets = ["get_iris_data"]
 _objects = ["write_object", "read_object", "read_script_as_module"]
 _tables = ["read_dataframe", "write_dataframe", "read_multiple_synopsis"]
-_text = ["read_textfile", "get_file_object"]
+_text = ["read_textfile", "get_file_object", "read_from_clipboard"]
 _web = ["read_url"]
 
-__all__ = _bioinformatics + _objects + _tables + _text + _web
+
+__all__ = _bioinformatics + _datasets + _objects + _tables + _text + _web
 __all__ = sorted(__all__)
