@@ -39,7 +39,7 @@ add_objects_to_globals(hx, functions_from_hive_networkx, globals(), add_version=
 
 # ensemble_networkx
 import ensemble_networkx as enx
-functions_from_ensemble_networkx= {"EnsembleAssociationNetwork", "SampleSpecificPerturbationNetwork"}
+functions_from_ensemble_networkx= {"EnsembleAssociationNetwork", "SampleSpecificPerturbationNetwork", "DifferentialEnsembleAssociationNetwork"}
 add_objects_to_globals(enx, functions_from_ensemble_networkx, globals(), add_version=True, __all__=__all__)
 
 
